using System;
using System.ComponentModel;
using System.Text;

namespace DataBindingFundamentalsSample
{
    public class RaceCarDrivers : BindingList<RaceCarDriver>, IComponent
    {
        #region IComponent Members

        ISite site = null;

        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Browsable(false)]
        public ISite Site
        {
            get { return site; }
            set { site = value; }
        }

        public event EventHandler Disposed;

        public void Dispose()
        {
            this.Dispose(true);
        }

        protected virtual void Dispose(bool disposing)
        {
            if (disposing)
            {
                lock (this)
                {
                    if (this.Disposed != null) this.Disposed(this, EventArgs.Empty);
                }
            }
        }

        #endregion
    }

    public class RaceCarDriver : INotifyPropertyChanged
    {
        private void OnPropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        #endregion

        private string name;
        private int wins;

        // Needed so DGV can add new rows
        public RaceCarDriver() { }

        public RaceCarDriver(string name, int wins)
        {
            this.name = name;
            this.wins = wins;
        }

        public string Name
        {
            get { return this.name; }
            set
            {
                this.name = value;
                this.OnPropertyChanged("Name");
            }
        }

        public int Wins
        {
            get { return this.wins; }
            set
            {
                this.wins = value;
                this.OnPropertyChanged("Wins");
            }
        }

        public override string ToString()
        {
            return String.Format("Name: {0}, Wins: {1}", Name, Wins);
        }

        //public event EventHandler NameChanged;
        //public event EventHandler WinsChanged;


    }
}
